==> form-utils-react-hooks-0.0.5.tgz: package/esm/hooks/register/register.FormItem.js <==
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__ from "@carefrees/form-utils";
import * as __WEBPACK_EXTERNAL_MODULE__useUpdate_js_b5f1687a__ from "../useUpdate.js";
import * as __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__ from "../useForm.js";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItem_js_cd5761e5__ from "../useFormItem.js";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__ from "../useFormItemParentName.js";
const useRegisterFormItem = (options)=>{
    const { name, rules, sort, isJoinParentField = true } = options;
    const form = (0, __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__.useFormInstance)();
    const { newName, newSort, parentName } = (0, __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__.useFormItemParentName)({
        name,
        sort,
        isJoinParentField
    });
    const ruleInstance = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)(new __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__.RuleInstanceBase()).current;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useMemo)(()=>ruleInstance.ctor(newName, rules), [
        rules,
        newName
    ]);
    ruleInstance.instance = form;
    ruleInstance.sort = newSort;
    const formItemInstance = (0, __WEBPACK_EXTERNAL_MODULE__useFormItem_js_cd5761e5__.useFormItem)();
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useMemo)(()=>formItemInstance.ctor(newName, ruleInstance), []);
    formItemInstance.instance = form;
    formItemInstance.sort = newSort;
    formItemInstance.parentDataField = parentName;
    const _updated = (0, __WEBPACK_EXTERNAL_MODULE__useUpdate_js_b5f1687a__.useUpdate)();
    formItemInstance.updated = _updated.current;
    ruleInstance.updated = _updated.current;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useEffect)(()=>{
        const unMount = form.registerFormItem(formItemInstance);
        return ()=>unMount();
    }, []);
    return {
        ruleInstance,
        formItemInstance,
        form,
        parentName,
        newName
    };
};
export { useRegisterFormItem };

==> form-utils-react-hooks-0.0.8.tgz: package/esm/hooks/register/register.FormItem.js <==
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__ from "@carefrees/form-utils";
import * as __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__ from "../useForm.js";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItem_js_cd5761e5__ from "../useFormItem.js";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__ from "../useFormItemParentName.js";
const useRegisterFormItem = (options)=>{
    const { name, rules, sort, isJoinParentField = true } = options;
    const form = (0, __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__.useFormInstance)();
    const { newName, newSort, parentName } = (0, __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__.useFormItemParentName)({
        name,
        sort,
        isJoinParentField
    });
    const [, setValue] = (0, __WEBPACK_EXTERNAL_MODULE_react__.useState)({});
    const ruleInstance = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)(new __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__.RuleInstanceBase()).current;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useMemo)(()=>ruleInstance.ctor(newName, rules), [
        rules,
        newName
    ]);
    ruleInstance.instance = form;
    ruleInstance.sort = newSort;
    const formItemInstance = (0, __WEBPACK_EXTERNAL_MODULE__useFormItem_js_cd5761e5__.useFormItem)();
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useMemo)(()=>formItemInstance.ctor(newName, ruleInstance), []);
    formItemInstance.instance = form;
    formItemInstance.sort = newSort;
    formItemInstance.parentDataField = parentName;
    formItemInstance.updated = setValue;
    ruleInstance.updated = setValue;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useEffect)(()=>{
        const unMount = form.registerFormItem(formItemInstance);
        return ()=>unMount();
    }, []);
    return {
        ruleInstance,
        formItemInstance,
        form,
        parentName,
        newName
    };
};
export { useRegisterFormItem };
